@@ -127,6 +127,7 @@ names( txtcolorlego ) <- c( "red", "green", "blue" )
   par( new = TRUE )
   par( fig = c( 0.0150, 0.5000, 0.2332,  0.5700 ) )
   color <- vfgrayscale( vf0, vfinfo0$sage, pattern =  vfinfo0$tpattern, algorithm = vfinfo0$talgorithm )
+  vf0[which( vf0 < 0 )] <- "<0"
   vfplotloc( vf0, eye = vfinfo0$seye, patternMap = locmap , outerColor = color, bs = c( vfinfo0$sbsx, vfinfo0$sbsy ), 
              txtfont = ffmailyvf, pointsize = pointsize,
              xminmax = xminmax, yminmax = yminmax,
@@ -136,7 +137,8 @@ names( txtcolorlego ) <- c( "red", "green", "blue" )
   # sensitivity plot last n visits
   par( new = TRUE )
   par( fig = c( 0.5000, 0.985, 0.2332,  0.5700 ) )
-  color <- vfgrayscale( vf0, vfinfo0$sage, pattern =  vfinfo0$tpattern, algorithm = vfinfo0$talgorithm )
+  color <- vfgrayscale( vf1, vfinfo0$sage, pattern =  vfinfo0$tpattern, algorithm = vfinfo0$talgorithm )
+  vf1[which( vf1 < 0 ) ] <- "<0"
   vfplotloc( vf1, eye = vfinfo1$seye, patternMap = locmap , outerColor = color, bs = c( vfinfo0$sbsx, vfinfo0$sbsy ), 
              txtfont = ffmailyvf, pointsize = pointsize,
              xminmax = xminmax, yminmax = yminmax,
